/*
 * fr_fsops.c - Filesystem ops for fread
 * $Fuller: myprograms/fread/fr_fsops.c,v 1.1.1.1 2003/06/05 16:54:49 fullermd Exp $
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include <fread.h>


/* fr_open(): Open a file */
int
fr_open(FR_FILE *frfile)
{
	int desc;
	struct stat stret;

	/* Check that we're given something meaningful */
	if( (frfile==NULL) || (frfile->name==NULL) )
		return(-1);
	
	/* Make sure it's a file */
	if((stat(frfile->name, &stret))<0)
	{
		fprintf(stderr, "Error stat()'ing %s: %s\n", frfile->name,
				strerror(errno));
		return(-1);
	}

	if(!(stret.st_mode&S_IFREG))
	{
		fprintf(stderr, "Error: Only regular files are supported, sorry.\n");
		return(-1);
	}

	/* Try opening it */
	desc = open(frfile->name, O_RDONLY);
	if(desc<0)
	{
		fprintf(stderr, "Error open()'ing %s: %s", frfile->name,
				strerror(errno));
		return(-1);
	}

	/* If we got here, we're golden */
	frfile->desc = desc;
	return(0);
}


/* fr_close(): Close a file */
int
fr_close(FR_FILE *frfile)
{
	/* Check that we're given something meaningful */
	if( (frfile==NULL) || (frfile->desc==0) )
		return(-1);

	return(close(frfile->desc));
}
